#!/usr/bin/env ruby
require 'rubygems'
require 'active_support'
require 'optparse'

options = {}
optparser = OptionParser.new do |opts|
  opts.banner = "Usage: get_chef_attributes_versions.rb [options] ..."
end

optparser.parse!

out_path = ARGV[0]
cloud = ARGV[1]

class Cbook
  attr_accessor :version

  def initialize
    @version = ''
  end

  def maintainer(a)
  end
  def maintainer_email(a)
  end
  def license(a)
  end
  def description(a)
  end
  def long_description(a)
  end
  def version(a = nil)
    @version = a if !a.nil?
    @version
  end
  def depends(a)
  end
end


cbook_mdata = Cbook.new
f = "#{out_path}/chef-repo/cookbooks/webslave/metadata.rb"
f = "#{out_path}/chef-repo/cookbooks/#{cloud}_webslave/metadata.rb" if cloud != "aws"

cbook_mdata.instance_eval(IO.read(f))

puts cbook_mdata.version
exit(0)